class PagedQueryResult:

    def __init__(self,
                 total: int = None,
                 page: int = None,
                 size: int = None,
                 sort: str = None,
                 direction: str = None):
        self.total = total
        self.page = page
        if page < 0:
            raise ValueError("page must be a positive number")
        self.size = size
        if size < 0 or size > 100:
            raise ValueError("size is limited to 100")
        self.sort = sort
        if sort is None:
            raise ValueError("sort is mandatory")
        self.direction = direction
        if direction != 'asc' and direction != 'desc':
            raise ValueError("direction must be asc or desc")
        self.results = None



class ApiDto:

    def api_id(self) -> str:
        """
        return current object id on Web API format.
        """
        pass

    def endpoint(self) -> str:
        """
        return endpoint name in Web API (<0.4)
        """
        pass

    def to_json(self, target: str = None):
        """
        transform current object into a dict that could be JSONIFY.
        :target: by default - None. Can be 'backend-create' or 'backend-update' in order to JSONIFY only backend fields.
        :return: dumpable dict.
        """
        pass

    def from_json(self, obj):
        """
        load the object from a dict originating of a JSON format.
        :param obj: object to load information from.
        """
        pass

    @classmethod
    def route(cls):
        """
        Endpoint name in Web API (v0.4+).
        """
        pass

    @classmethod
    def from_dict(cls, data):
        """
        Init object instance from dict (v0.4+)
        """
        pass

    @classmethod
    def get_type(cls):
        """
        Return type of get format json by default - override with either pickle, dill, ...
        """
        return "json"
